@@ -1,15 +1,15 @@
 test_that("for_loop_index_linter skips allowed usages", {
   linter <- for_loop_index_linter()
 
-  expect_lint("for (xi in x) {}", NULL, linter)
+  expect_no_lint("for (xi in x) {}", linter)
 
   # this is OK, so not every symbol is problematic
-  expect_lint("for (col in DF$col) {}", NULL, linter)
-  expect_lint("for (col in S4@col) {}", NULL, linter)
-  expect_lint("for (col in DT[, col]) {}", NULL, linter)
+  expect_no_lint("for (col in DF$col) {}", linter)
+  expect_no_lint("for (col in S4@col) {}", linter)
+  expect_no_lint("for (col in DT[, col]) {}", linter)
 
   # make sure symbol check is scoped
-  expect_lint(
+  expect_no_lint(
     trim_some(
       "
       {
@@ -20,7 +20,6 @@ test_that("for_loop_index_linter skips allowed usages", {
       }
     "
     ),
-    NULL,
     linter
   )
 })
@@ -32,8 +31,8 @@ test_that("for_loop_index_linter blocks simple disallowed usages", {
   expect_lint("for (x in x) {}", lint_msg, linter)
   # these also overwrite a variable in calling scope
   expect_lint("for (x in foo(x)) {}", lint_msg, linter)
-  expect_lint("for (x in foo(x = 1)) {}", NULL, linter)
+  expect_no_lint("for (x in foo(x = 1)) {}", linter)
   # arbitrary nesting
   expect_lint("for (x in foo(bar(y, baz(2, x)))) {}", lint_msg, linter)
-  expect_lint("for (x in foo(bar(y, baz(2, x = z)))) {}", NULL, linter)
+  expect_no_lint("for (x in foo(bar(y, baz(2, x = z)))) {}", linter)
 })
