@@ -1,7 +1,7 @@
 test_that("browser() call detected", {
   linter <- undesirable_function_linter()
   expect_lint("browser()", "Function \"browser()\" is undesirable", linter)
-  expect_lint("#browser()", NULL, linter)
+  expect_no_lint("#browser()", linter)
 })
 
 test_that("browser() has no fix", {
@@ -11,12 +11,12 @@ test_that("browser() has no fix", {
 test_that("debugonce() call detected", {
   linter <- undesirable_function_linter()
   expect_lint("debugonce()", "Function \"debugonce()\" is undesirable", linter)
-  expect_lint("#debugonce()", NULL, linter)
+  expect_no_lint("#debugonce()", linter)
 })
 
 test_that("those names can be used as argument names, not as values", {
   linter <- undesirable_function_linter()
-  expect_lint("foo(browser = TRUE)", NULL, linter)
+  expect_no_lint("foo(browser = TRUE)", linter)
   expect_lint(
     "foo(x = browser())",
     "Function \"browser()\" is undesirable",
